@@ -19,79 +19,75 @@
 
 One for each type of call. """
 
-from nuitka.nodes.FunctionNodes import (
-    ExpressionFunctionBody,
-    ExpressionFunctionCreation,
-    ExpressionFunctionCall,
-    ExpressionFunctionRef
+from nuitka.nodes.AssignNodes import (
+    StatementAssignmentSubscript,
+    StatementAssignmentVariable,
+    StatementDelVariable
 )
-from nuitka.nodes.StatementNodes import (
-    StatementsSequence,
-    StatementsFrame
-)
-from nuitka.nodes.LoopNodes import (
-    StatementLoop,
-    StatementBreakLoop
-)
-from nuitka.nodes.TypeNodes import (
-    ExpressionBuiltinIsinstance,
-    ExpressionBuiltinType1
+from nuitka.nodes.AttributeNodes import ExpressionAttributeLookup
+from nuitka.nodes.BuiltinDictNodes import ExpressionBuiltinDict
+from nuitka.nodes.BuiltinIteratorNodes import (
+    ExpressionBuiltinIter1,
+    ExpressionBuiltinNext1
 )
 from nuitka.nodes.BuiltinRefNodes import (
     ExpressionBuiltinAnonymousRef,
     ExpressionBuiltinRef
 )
-from nuitka.nodes.ConditionalNodes import StatementConditional
+from nuitka.nodes.BuiltinTypeNodes import ExpressionBuiltinTuple
+from nuitka.nodes.CallNodes import (
+    ExpressionCall,
+    ExpressionCallEmpty,
+    ExpressionCallKeywordsOnly,
+    ExpressionCallNoKeywords
+)
 from nuitka.nodes.ComparisonNodes import ExpressionComparison
+from nuitka.nodes.ConditionalNodes import StatementConditional
+from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
+from nuitka.nodes.ContainerMakingNodes import ExpressionMakeTuple
+from nuitka.nodes.ExceptionNodes import (
+    ExpressionBuiltinMakeException,
+    StatementRaiseException
+)
+from nuitka.nodes.FunctionNodes import (
+    ExpressionFunctionBody,
+    ExpressionFunctionCall,
+    ExpressionFunctionCreation,
+    ExpressionFunctionRef
+)
+from nuitka.nodes.FutureSpecs import FutureSpec
+from nuitka.nodes.LoopNodes import StatementBreakLoop, StatementLoop
+from nuitka.nodes.ModuleNodes import PythonInternalModule
+from nuitka.nodes.OperatorNodes import (
+    ExpressionOperationBinary,
+    ExpressionOperationNOT
+)
+from nuitka.nodes.ParameterSpecs import ParameterSpec
+from nuitka.nodes.ReturnNodes import StatementReturn
+from nuitka.nodes.StatementNodes import StatementsSequence
+from nuitka.nodes.SubscriptNodes import ExpressionSubscriptLookup
+from nuitka.nodes.TypeNodes import (
+    ExpressionBuiltinIsinstance,
+    ExpressionBuiltinType1
+)
 from nuitka.nodes.VariableRefNodes import (
     ExpressionTargetTempVariableRef,
     ExpressionTargetVariableRef,
     ExpressionTempVariableRef,
     ExpressionVariableRef
 )
-from nuitka.nodes.CallNodes import (
-    ExpressionCallKeywordsOnly,
-    ExpressionCallNoKeywords,
-    ExpressionCallEmpty,
-    ExpressionCall
-)
-from nuitka.nodes.ReturnNodes import StatementReturn
-from nuitka.nodes.AssignNodes import (
-    StatementAssignmentVariable,
-    StatementAssignmentSubscript
-)
-from nuitka.nodes.ExceptionNodes import (
-    StatementRaiseException,
-    ExpressionBuiltinMakeException
-)
-from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
-from nuitka.nodes.AttributeNodes import ExpressionAttributeLookup
-from nuitka.nodes.ContainerMakingNodes import ExpressionMakeTuple
-from nuitka.nodes.BuiltinTypeNodes import ExpressionBuiltinTuple
-from nuitka.nodes.OperatorNodes import (
-    ExpressionOperationBinary,
-    ExpressionOperationNOT
-)
-from nuitka.nodes.BuiltinIteratorNodes import (
-    ExpressionBuiltinIter1,
-    ExpressionBuiltinNext1
-)
-from nuitka.nodes.SubscriptNodes import ExpressionSubscriptLookup
-from nuitka.nodes.BuiltinDictNodes import ExpressionBuiltinDict
-from nuitka.nodes.ModuleNodes import PythonInternalModule
-
-from nuitka.nodes.ParameterSpecs import ParameterSpec
-from nuitka.nodes.FutureSpecs import FutureSpec
-
 from nuitka.SourceCodeReferences import fromFilename
+from nuitka.Utils import python_version
 
+from .Helpers import (
+    makeStatementsSequenceFromStatement,
+    makeTryFinallyStatement
+)
 from .ReformulationTryExceptStatements import makeTryExceptSingleHandlerNode
 from .VariableClosure import completeVariableClosures
-from .Helpers import makeStatementsSequenceFromStatement
 
-source_ref = fromFilename( "internal", FutureSpec() ).atInternal()
+source_ref = fromFilename("internal", FutureSpec()).atInternal()
 
-from nuitka.Utils import python_version
 
 # Cache result. TODO: no more as special as it used to be, maybe can be found in
 # stdlib.
@@ -169,24 +165,6 @@ def makeStarDictArgVariableRef(assign):
 
     return variable_ref
 
-# TODO: Code generation should become capable of not generating actual
-# exceptions for the TypeError caught immediately and then unused, then the
-# frame will be unnecessary.
-
-def makePseudoFrame(parameters, statements):
-    return StatementsFrame(
-        code_name     = "unused",
-        guard_mode    = "pass_through",
-        var_names     = parameters.getParameterNames(),
-        arg_count     = parameters.getArgumentCount(),
-        has_starlist  = parameters.getStarListArgumentName() is not None,
-        has_stardict  = parameters.getStarDictArgumentName() is not None,
-        kw_only_count = 0,
-        statements    = statements,
-        source_ref    = source_ref
-    )
-
-
 @once_decorator
 def getCallableNameDescBody():
     helper_name = "get_callable_name_desc"
@@ -382,13 +360,13 @@ def getCallableNameDescBody():
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
-def _makeStarListArgumentToTupleStatement( called_variable_ref,
-                                           star_list_target_variable_ref,
-                                           star_list_variable_ref ):
+def _makeStarListArgumentToTupleStatement(called_variable_ref,
+                                          star_list_target_variable_ref,
+                                          star_list_variable_ref):
     raise_statement = StatementRaiseException(
         exception_type  = ExpressionBuiltinMakeException(
             exception_name = "TypeError",
@@ -463,7 +441,9 @@ def _makeStarListArgumentToTupleStatement( called_variable_ref,
                     statement = StatementAssignmentVariable(
                         variable_ref = star_list_target_variable_ref.makeCloneAt( source_ref ),
                         source       = ExpressionBuiltinTuple(
-                            value      = star_list_variable_ref.makeCloneAt( source_ref ),
+                            value      = star_list_variable_ref.makeCloneAt(
+                                source_ref
+                            ),
                             source_ref = source_ref
                         ),
                         source_ref   = source_ref
@@ -471,6 +451,7 @@ def _makeStarListArgumentToTupleStatement( called_variable_ref,
                 ),
                 exception_name = "TypeError",
                 handler_body   = handler_body,
+                public_exc     = False,
                 source_ref     = source_ref
             ),
         ),
@@ -479,9 +460,9 @@ def _makeStarListArgumentToTupleStatement( called_variable_ref,
     )
 
 
-def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
-                                          star_dict_target_variable_ref,
-                                          star_dict_variable_ref ):
+def _makeStarDictArgumentToDictStatement(result, called_variable_ref,
+                                         star_dict_target_variable_ref,
+                                         star_dict_variable_ref):
     raise_statement = StatementRaiseException(
         exception_type  = ExpressionBuiltinMakeException(
             exception_name = "TypeError",
@@ -534,12 +515,12 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
         source_ref      = source_ref
     )
 
-    temp_scope = result.allocateTempScope( "mapping" )
+    temp_scope = result.allocateTempScope("mapping")
 
-    tmp_dict_variable = result.allocateTempVariable( temp_scope,  "dict" )
-    tmp_iter_variable = result.allocateTempVariable( temp_scope,  "iter" )
-    tmp_keys_variable = result.allocateTempVariable( temp_scope,  "keys" )
-    tmp_key_variable = result.allocateTempVariable( temp_scope,  "key" )
+    tmp_dict_variable = result.allocateTempVariable(temp_scope, "dict")
+    tmp_iter_variable = result.allocateTempVariable(temp_scope, "iter")
+    tmp_keys_variable = result.allocateTempVariable(temp_scope, "keys")
+    tmp_key_variable = result.allocateTempVariable(temp_scope, "key")
 
     statements = (
         makeTryExceptSingleHandlerNode(
@@ -569,21 +550,22 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
                     source_ref = source_ref
                 )
             ),
+            public_exc     = False,
             source_ref     = source_ref
         ),
         StatementAssignmentSubscript(
             expression = ExpressionTempVariableRef(
-                variable   = tmp_dict_variable.makeReference( result ),
+                variable   = tmp_dict_variable.makeReference(result),
                 source_ref = source_ref
             ),
             subscript  = ExpressionTempVariableRef(
-                variable   = tmp_key_variable.makeReference( result ),
+                variable   = tmp_key_variable.makeReference(result),
                 source_ref = source_ref
             ),
             source     = ExpressionSubscriptLookup(
-                expression = star_dict_variable_ref.makeCloneAt( source_ref ),
+                expression = star_dict_variable_ref.makeCloneAt(source_ref),
                 subscript  = ExpressionTempVariableRef(
-                    variable   = tmp_key_variable.makeReference( result ),
+                    variable   = tmp_key_variable.makeReference(result),
                     source_ref = source_ref
                 ),
                 source_ref = source_ref
@@ -603,7 +585,7 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
         # removed once code generation is apt enough.
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_keys_variable.makeReference( result ),
+                variable   = tmp_keys_variable.makeReference(result),
                 source_ref = source_ref
             ),
             source     = ExpressionConstantRef(
@@ -617,12 +599,14 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
             tried          = makeStatementsSequenceFromStatement(
                 statement = StatementAssignmentVariable(
                     variable_ref = ExpressionTargetTempVariableRef(
-                        variable   = tmp_keys_variable.makeReference( result ),
+                        variable   = tmp_keys_variable.makeReference(result),
                         source_ref = source_ref
                     ),
                     source     = ExpressionCallEmpty(
                         called = ExpressionAttributeLookup(
-                            expression     = star_dict_variable_ref.makeCloneAt( source_ref ),
+                            expression     = star_dict_variable_ref.makeCloneAt(
+                                source_ref
+                            ),
                             attribute_name = "keys",
                             source_ref     = source_ref
                         ),
@@ -635,16 +619,17 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
             handler_body   = makeStatementsSequenceFromStatement(
                 statement = raise_statement
             ),
+            public_exc     = False,
             source_ref     = source_ref
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_iter_variable.makeReference( result ),
+                variable   = tmp_iter_variable.makeReference(result),
                 source_ref = source_ref
             ),
             source     = ExpressionBuiltinIter1(
                 value      = ExpressionTempVariableRef(
-                    variable   = tmp_keys_variable.makeReference( result ),
+                    variable   = tmp_keys_variable.makeReference(result),
                     source_ref = source_ref
                 ),
                 source_ref = source_ref
@@ -653,7 +638,7 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_dict_variable.makeReference( result ),
+                variable   = tmp_dict_variable.makeReference(result),
                 source_ref = source_ref
             ),
             source     = ExpressionConstantRef(
@@ -684,24 +669,65 @@ def _makeStarDictArgumentToDictStatement( result, called_variable_ref,
         source_ref = source_ref
     )
 
-    return StatementConditional(
-            condition  = ExpressionOperationNOT(
-                operand    = ExpressionBuiltinIsinstance(
-                    instance   = star_dict_variable_ref.makeCloneAt(
-                        source_ref = source_ref
-                    ),
-                    cls        = ExpressionBuiltinRef(
-                        builtin_name = "dict",
-                        source_ref   = source_ref
-                    ),
+    tried = StatementConditional(
+        condition  = ExpressionOperationNOT(
+            operand    = ExpressionBuiltinIsinstance(
+                instance   = star_dict_variable_ref.makeCloneAt(
                     source_ref = source_ref
                 ),
+                cls        = ExpressionBuiltinRef(
+                    builtin_name = "dict",
+                    source_ref   = source_ref
+                ),
                 source_ref = source_ref
             ),
-            yes_branch = mapping_case,
-            no_branch  = None,
             source_ref = source_ref
+        ),
+        yes_branch = mapping_case,
+        no_branch  = None,
+        source_ref = source_ref
+    )
+
+    final = (
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_dict_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_iter_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_keys_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_key_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
         )
+    )
+
+    return makeTryFinallyStatement(
+        tried      = tried,
+        final      = final,
+        source_ref = source_ref
+    )
 
 
 def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
@@ -764,12 +790,47 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
         source_ref      = source_ref
     )
 
-    temp_scope = result.allocateTempScope( "dict" )
+    temp_scope = result.allocateTempScope("dict")
 
-    tmp_dict_variable = result.allocateTempVariable( temp_scope,  "dict" )
-    tmp_keys_variable = result.allocateTempVariable( temp_scope,  "keys" )
-    tmp_key_variable = result.allocateTempVariable( temp_scope,  "key_xxx" )
-    tmp_iter_variable = result.allocateTempVariable( temp_scope,  "iter" )
+    tmp_dict_variable = result.allocateTempVariable(temp_scope, "dict")
+    tmp_iter_variable = result.allocateTempVariable(temp_scope, "iter")
+    tmp_keys_variable = result.allocateTempVariable(temp_scope, "keys")
+    tmp_key_variable = result.allocateTempVariable(temp_scope, "key_xxx")
+
+    final = [
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_dict_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_iter_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_keys_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_key_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        )
+    ]
 
     raise_duplicate = StatementRaiseException(
         exception_type  = ExpressionBuiltinMakeException(
@@ -829,7 +890,7 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
             tried          = makeStatementsSequenceFromStatement(
                 statement = StatementAssignmentVariable(
                     variable_ref = ExpressionTargetTempVariableRef(
-                        variable   = tmp_key_variable.makeReference( result ),
+                        variable   = tmp_key_variable.makeReference(result),
                         source_ref = source_ref
                     ),
                     source     = ExpressionBuiltinNext1(
@@ -850,16 +911,17 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
                     source_ref = source_ref
                 )
             ),
+            public_exc     = False,
             source_ref     = source_ref
         ),
         StatementConditional(
             condition = ExpressionComparison(
                 comparator = "In",
                 left       = ExpressionTempVariableRef(
-                    variable   = tmp_key_variable.makeReference( result ),
+                    variable   = tmp_key_variable.makeReference(result),
                     source_ref = source_ref
                 ),
-                right      = kw_variable_ref.makeCloneAt( source_ref ),
+                right      = kw_variable_ref.makeCloneAt(source_ref),
                 source_ref = source_ref
             ),
             yes_branch = makeStatementsSequenceFromStatement(
@@ -931,7 +993,8 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
             handler_body   = makeStatementsSequenceFromStatement(
                 statement = raise_statement
             ),
-            source_ref = source_ref
+            public_exc     = False,
+            source_ref     = source_ref
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
@@ -949,7 +1012,7 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_dict_variable.makeReference( result ),
+                variable   = tmp_dict_variable.makeReference(result),
                 source_ref = source_ref
             ),
             source     = ExpressionConstantRef(
@@ -970,11 +1033,38 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
         source_ref = source_ref
     )
 
-    temp_scope = result.allocateTempScope( "dict" )
+    temp_scope = result.allocateTempScope("dict")
 
-    tmp_iter_variable = result.allocateTempVariable( temp_scope,  "iter" )
-    tmp_item_variable = result.allocateTempVariable( temp_scope,  "item" )
-    tmp_key_variable = result.allocateTempVariable( temp_scope,  "key" )
+    tmp_iter_variable = result.allocateTempVariable(temp_scope, "iter")
+    tmp_item_variable = result.allocateTempVariable(temp_scope, "item")
+    tmp_key_variable = result.allocateTempVariable(temp_scope, "key")
+
+    final += [
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_iter_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_item_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        ),
+        StatementDelVariable(
+            variable_ref = ExpressionTargetTempVariableRef(
+                variable   = tmp_key_variable.makeReference(result),
+                source_ref = source_ref
+            ),
+            tolerant     = True,
+            source_ref   = source_ref,
+        )
+    ]
 
     # TODO: Duplication from above, just so the other temp is used.
     raise_duplicate = StatementRaiseException(
@@ -1054,6 +1144,7 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
             handler_body   = makeStatementsSequenceFromStatement(
                 statement = StatementBreakLoop( source_ref )
             ),
+            public_exc     = False,
             source_ref     = source_ref
         ),
         StatementAssignmentVariable(
@@ -1175,7 +1266,7 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
         source_ref = source_ref
     )
 
-    return StatementConditional(
+    tried = StatementConditional(
         condition  = ExpressionOperationNOT(
             operand    = ExpressionBuiltinIsinstance(
                 instance   = star_dict_variable_ref.makeCloneAt( source_ref ),
@@ -1192,6 +1283,12 @@ def _makeStarDictArgumentMergeToKwStatement( result, called_variable_ref,
         source_ref = source_ref
     )
 
+    return makeTryFinallyStatement(
+        tried      = tried,
+        final      = final,
+        source_ref = source_ref
+    )
+
 
 @once_decorator
 def getFunctionCallHelperStarList():
@@ -1252,13 +1349,13 @@ def getFunctionCallHelperStarList():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1322,13 +1419,13 @@ def getFunctionCallHelperKeywordsStarList():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1396,13 +1493,13 @@ def getFunctionCallHelperPosStarList():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1471,9 +1568,9 @@ def getFunctionCallHelperPosKeywordsStarList():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
@@ -1554,13 +1651,13 @@ def getFunctionCallHelperStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1638,13 +1735,13 @@ def getFunctionCallHelperPosStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1729,8 +1826,8 @@ def getFunctionCallHelperKeywordsStarDict():
         _makeStarDictArgumentMergeToKwStatement(
             result                        = result,
             called_variable_ref           = makeCalledVariableRef(),
-            kw_variable_ref               = makeKwVariableRef( assign = False ),
-            kw_target_variable_ref        = makeKwVariableRef( assign = True ),
+            kw_variable_ref               = makeKwVariableRef(assign = False),
+            kw_target_variable_ref        = makeKwVariableRef(assign = True),
             star_dict_variable_ref        = makeStarDictArgVariableRef(
                 assign = False
             )
@@ -1738,7 +1835,7 @@ def getFunctionCallHelperKeywordsStarDict():
         StatementReturn(
             expression = ExpressionCallKeywordsOnly(
                 called     = makeCalledVariableRef(),
-                kw         = makeKwVariableRef( assign = False ),
+                kw         = makeKwVariableRef(assign = False),
                 source_ref = source_ref
             ),
             source_ref = source_ref
@@ -1746,13 +1843,13 @@ def getFunctionCallHelperKeywordsStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1855,13 +1952,13 @@ def getFunctionCallHelperPosKeywordsStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1919,13 +2016,13 @@ def getFunctionCallHelperStarListStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -1990,13 +2087,13 @@ def getFunctionCallHelperPosStarListStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -2055,13 +2152,12 @@ def getFunctionCallHelperKeywordsStarListStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
-
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
 
@@ -2125,12 +2221,12 @@ def getFunctionCallHelperPosKeywordsStarListStarDict():
     )
 
     result.setBody(
-        makePseudoFrame(
-            parameters = result.getParameters(),
-            statements = statements
+        StatementsSequence(
+            statements = statements,
+            source_ref = source_ref
         )
     )
 
-    completeVariableClosures( result )
+    completeVariableClosures(result)
 
     return result
